@@ -93,11 +93,7 @@ infotheo.default <- function(x, y, features="all", summary=c("mean", "sd"),
     y <- y[, 1]
   }
   y <- as.factor(y)
-  
-  if (nlevels(y) > length(y) / 10) {
-    stop("y must contain classes values")
-  }
-  
+
   if(min(table(y)) < 2) {
     stop("number of examples in the minority class should be >= 2")
   }
@@ -110,7 +106,7 @@ infotheo.default <- function(x, y, features="all", summary=c("mean", "sd"),
     features <- ls.infotheo()
   }
   features <- match.arg(features, ls.infotheo(), TRUE)
-  colnames(x) <- make.names(colnames(x))
+  colnames(x) <- make.names(colnames(x), unique=TRUE)
   
   if (length(summary) == 0) {
     summary <- "non.aggregated"
