@@ -26,8 +26,6 @@ test_that("statistical.errors",{
   #Test errors cases
   expect_error(statistical(iris[1:130, 1:4], iris[5]),
                "x and y must have same number of rows")
-  expect_error(statistical(iris[, 1:4], iris[,3]),
-               "y must contain classes values")
   expect_error(statistical(as.matrix(iris[, c(1,2)]), iris$Species),
                "data argument must be a data.frame")
   expect_error(statistical(Species ~ ., iris, features=c("abc", "xdef")))
